.notifications button[name="single_mark"] {
    display: none;
}

.notifications li.unread {
    cursor: pointer;
    font-weight: bold;
}

#notificationBtn {
    background-color: rgb(245, 245, 245);
    border: 1px solid rgba(0, 0, 0, 0.1);
    border-radius: 4px;
    box-shadow: rgba(255, 255, 255, 0.2) 0px 1px 0px 0px inset, rgba(0, 0, 0, 0.0470588) 0px 1px 2px 0px;
    color: rgb(51, 51, 51);
    display: inline-block;
    font-size: 12px;
    height: 20px;
    line-height: 20px;
    margin: 0 0 0 7px;
    padding: 4px 10px;
    text-align: center;
    text-decoration: none;
    text-shadow: rgba(255, 255, 255, 0.74902) 0px 1px 1px;
    vertical-align: middle;
    white-space: nowrap;
}

#notificationBtn .badge {
    background-color: rgb(153, 153, 153);
    border-bottom-left-radius: 9px;
    border-bottom-right-radius: 9px;
    border-top-left-radius: 9px;
    border-top-right-radius: 9px;
    color: rgb(255, 255, 255);
    cursor: pointer;
    float: left;
    font-size: 10px;
    font-weight: bold;
    height: auto;
    line-height: 13px;
    margin-right: 4px;
    margin-top: 3px;
    padding: 2px 5px;
    position: relative;
    text-align: center;
    text-shadow: rgba(0, 0, 0, 0.247059) 0px -1px 0px;
    top: -1px;
    vertical-align: baseline;
    white-space: nowrap;
    width: auto;
}

#notificationBtn .badge.badge-important {
    background-color: rgb(170, 70, 70);
}