{% load i18n %}
{% trans "New updates have been made:" %}

{% for key, value in event_types.items %}
<ul>
    {% for object_event in value %}
        <li>{{ object_event }}</li>
    {% endfor %}
</ul>
{% endfor %}
--