<!DOCTYPE html>
<html lang="en"><head>
<meta charset="UTF-8">
<title></title>
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}object_events/css/object_events.css">
</head>
<body>
    {% block main %}{% endblock %}
    <script src="//ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js"></script>
    <script type="text/javascript" src="{{ STATIC_URL }}object_events/js/object_events.js"></script>
</body>
</html>